%define ALD_Ver		1.2.4

Name:         diffutils

License:      GPL
Summary:      GNU dif and cmp utilities
Group:        Development/Tools
Version:      2.8.1
Release:      2

Source: %{name}-%{version}.tar.xz
Source1: CROSS.sh

%define DestDir		/text
# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
%define target %{_arch}-%{_vendor}-%{_os}%{__isa_bits}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif
%define target_  %{target}-

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin

%define __os_install_post %{nil}

%define CrossDestDir	/Cross

%define _srcrpmdir %{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysdir		%{nil}
%define csysbindir	/usr/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir %{_topdir}/SRPMS/%{ALD_Ver}

%define target %{_arch}-%{_os}%{_gnu}
%define target_  %{nil}

%endif # !_CROSS || !TARGETBUILD_CROSS

%define docdir %{_defaultdocdir}/%{name}

# ------------------- description ------------------------------------
%description
This directory contains the GNU diff and cmp utilities.
#-------------------------------
%package diff3-sdiff
Summary:      diff3,sdiff
Group:        Documentation
%description diff3-sdiff
diff3,sdiff
#-------------------------------
%package info
Summary:      Info for %{name}
Group:        Documentation
%description info
Info for %{name}

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

GCC_VER_STR=`%{target_}gcc -dumpversion`
LDFLAGS=" "

%if %{_arch} == "i386"
OPTFLAGS="-Os -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
OPT47=`case $GCC_VER_STR in 4.[789].*) echo "-fno-asynchronous-unwind-tables" ;; esac`
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os"
OPT47=`case $GCC_VER_STR in 4.[789].*) echo "-fno-asynchronous-unwind-tables" ;; esac`
LDFLAGS=`case $GCC_VER_STR in 4.[56789].*) echo -static-libgcc ;; esac`
%endif
%if %{_arch} == "arm"
OPTFLAGS="-Os -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
OPT47=
%endif

CFLAGS="$OPTFLAGS $OPT47 -ffunction-sections -fdata-sections -fno-stack-protector -std=gnu99"
LDFLAGS="$LDFLAGS -Wl,--gc-sections"

%configure \
	--build=%{_build} \
%if %{_CROSS}
	--host=%{target} \
%endif
	--disable-nls \
	&>FConfigure_log.txt

make &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

%makeinstall

rm -rf $RPM_BUILD_ROOT%{_infodir}/dir

cp AUTHORS README THANKS $RPM_BUILD_ROOT%{docdir}/
ln -s /usr/share/doc/gpl-2.0.txt $RPM_BUILD_ROOT%{docdir}/COPYING

%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=0
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%endif #_CROSS

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} -r %{DestDir} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean
DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-diff3-sdiff-$SE $DD/%{name}-diff3-sdiff-$DE
  mv %{name}-info-$SE $DD/%{name}-info-$DE
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
  TMP_TO=$DD/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r usr $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
popd
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------
%files
%{_bindir}/cmp
%{_bindir}/diff
%{_mandir}/man1/cmp.1.gz
%{_mandir}/man1/diff.1.gz
%{docdir}

%files diff3-sdiff
%{_bindir}/diff3
%{_bindir}/sdiff
%{_mandir}/man1/diff3.1.gz
%{_mandir}/man1/sdiff.1.gz

%files info
%{_infodir}
